@@ -31,7 +31,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.40';
+our $VERSION = '2.41';
 
 =head1 SYNOPSIS
 
@@ -129,6 +129,7 @@ has 'module' => (
     isa => 'ArrayRef',
     required => 0,
     documentation => q{List of modules to load ex. R2, samtools, etc},
+    default => sub {[]},
 );
 
 =head2 jobname
@@ -178,6 +179,8 @@ has 'cpus_per_task' => (
     isa => 'Str',
     required => 0,
     default => 4,
+    predicate => 'has_cpus_per_task',
+    clearer => 'clear_cpus_per_task'
 );
 
 =head2 commands_per_node
@@ -192,6 +195,8 @@ has 'commands_per_node' => (
     required => 0,
     default => 8,
     documentation => q{Commands to run on each node. This is not the same as concurrent_commands_per_node!},
+    predicate => 'has_commands_per_node',
+    clearer => 'clear_commands_per_node'
 );
 
 =head2 partition
@@ -207,7 +212,9 @@ has 'partition' => (
     isa => 'Str',
     required => 0,
     default => '',
-    documentation => q{Slurm partition to submit jobs to. Defaults to the partition with the most available nodes}
+    documentation => q{Slurm partition to submit jobs to. Defaults to the partition with the most available nodes},
+    predicate => 'has_partition',
+    clearer => 'clear_partition'
 );
 
 =head2 nodelist
@@ -248,7 +255,7 @@ One is generated here for you, but you can always supply your own with --templat
 =cut
 
 has 'template_file' => (
-    traits => ['NoGetopt'],
+    #traits => ['NoGetopt'],
     is => 'rw',
     isa => 'Str',
     default => sub {
@@ -269,7 +276,9 @@ has 'template_file' => (
 [% IF NODE %]
 #SBATCH --nodelist=[% NODE %]
 [% END %]
+[% IF CPU %]
 #SBATCH --cpus-per-task=[% CPU %]
+[% END %]
 [% IF AFTEROK %]
 #SBATCH --dependency=afterok:[% AFTEROK %]
 [% END %]
@@ -286,6 +295,8 @@ EOF
         print $fh $tt;
         return $filename;
     },
+    predicate => 'has_template_file',
+    clearer => 'clear_template_file'
 );
 
 
@@ -299,7 +310,9 @@ has serial => (
     is        => 'rw',
     isa     => 'Bool',
     default => 0,
-    documentation => q{Use this if you wish to run each job run one after another, with each job starting only after the previous has completed successfully}
+    documentation => q{Use this if you wish to run each job run one after another, with each job starting only after the previous has completed successfully},
+    predicate => 'has_serial',
+    clearer => 'clear_serial'
 );
 
 
@@ -374,12 +387,15 @@ has 'use_custom' => (
     default => 0,
     required => 0,
     documentation => q{Use custom command to run jobs},
+    predicate => 'has_use_custom',
+    clearer => 'clear_use_custom',
 );
 
 has 'custom_command' => (
     is => 'rw',
     isa => 'Str',
     predicate => 'has_custom_command',
+    clearer => 'clear_custom_command',
     default => q{},
 );
 
@@ -843,11 +859,28 @@ echo "This is my new job with new HPC params!"
 sub check_meta{
     my $self = shift;
     my $line = shift;
+    my(@match, $t1, $t2);
+
+    @match = $line =~ m/HPC (\w+)=(.+)$/;
+    ($t1, $t2)  = ($match[0], $match[1]);
 
-    my(@match) = $line =~ m/HPC (\w+)=(\w+)/;
     $DB::single=2;
-    my($t1, $t2)  = ($match[0], $match[1]);
-    $self->$t1($t2);
+    if($t1){
+        if($t1 eq "module"){
+            $self->$t1([$t2]);
+        }
+        else{
+            $self->$t1($t2);
+        }
+    }
+    else{
+        @match = $line =~ m/HPC (\w+)$/;
+        $DB::single=2;
+        $t1 = $match[0];
+        return unless $t1;
+        $t1 = "clear_$t1";
+        $self->$t1;
+    }
 }
 
 =head2 work
